angular.module('manageScoringApp', [
    'ngRoute',
    'manageScoring',
    'manageProfiles',
    'wemServices',
    'wemDirectives',
    'i18n'
])
    .config(['$routeProvider',
        function ($routeProvider) {
            $routeProvider.
                when('/scoring', {
                    templateUrl: ManagersContext.localTemplatesPath + '/scoring/scoring-list.html',
                    controller: 'ManageScoringListCtrl',
                    reloadOnSearch: false
                }).
                when('/scoring/:scoringId', {
                    templateUrl: ManagersContext.localTemplatesPath + '/scoring/scoring-edit.html',
                    controller: 'ManageScoringCtrl',
                    resolve: {
                        // resolve rule here to avoid async issue using deferred API
                        "currentNotifRule": function ($q, $route, ruleService) {
                            var notifRule = $q.defer();
                            ruleService.getRule("sendEmailRulePrefix_" + $route.current.params.scoringId).success(function (ruleData) {
                                if(ruleData.itemId && ruleData.metadata.enabled){
                                    var thresholdCond = _.find(ruleData.condition.parameterValues.subConditions, function (sub) {
                                        if(sub.type === "eventPropertyCondition"){
                                            return true;
                                        }
                                    });
                                    notifRule.resolve({targetEmail: ruleData.actions[0].parameterValues.to, threshold: thresholdCond?thresholdCond.parameterValues.propertyValueInteger:0, emailNotifEnabled: true});
                                }else{
                                    notifRule.resolve(null);
                                }
                            });
                            return notifRule.promise;
                        },
                        "currentScoring": function ($q, $route, scoringService) {
                            var scoring = $q.defer();
                            scoringService.getScoring($route.current.params.scoringId).success(function (scoringData) {
                                scoring.resolve(scoringData);
                            });
                            return scoring.promise;
                        },
                        "newScoring": function () {
                            return false;
                        }
                    }
                }).
                when('/newScoring', {
                    templateUrl: ManagersContext.localTemplatesPath + '/scoring/scoring-edit.html',
                    controller: 'ManageScoringCtrl',
                    resolve: {
                        "currentNotifRule": function () {
                            return {};
                        },
                        "currentScoring": function ($route, scoringService, i18nService) {
                            var scoring = {};
                            if (scoringService.scoringToCopy) {
                                scoring = scoringService.scoringToCopy;
                                scoring.metadata.id = ManagersUtils.generateId();
                                scoring.metadata.name = i18nService.format('serverSettings.manageScoring.duplicate.name', scoringService.scoringToCopy.metadata.name);
                                scoring.metadata.tags = [];
                                delete scoringService.scoringToCopy;
                            } else {
                                scoring = {
                                    metadata: {
                                        id: ManagersUtils.generateId(),
                                        scope: ManagersContext.dmfScope,
                                        enabled: true
                                    },
                                    elements: [
                                        {
                                            condition: {},
                                            value: 1
                                        }
                                    ]
                                };
                            }
                            return scoring;
                        },
                        "newScoring": function () {
                            return true;
                        }
                    }
                }).
                when('/scoring/:scoringId/profiles', {
                    templateUrl: ManagersContext.localTemplatesPath + '/scoring/profiles-list.html',
                    controller: function ($scope, profileService) {
                        $scope.exportProfiles = function () {
                            var stringifyQuery = JSON.stringify(angular.copy(profileService.constructQueryOnCurrentSelectedTab(null, 0, -1, null)));
                            profileService.exportUsingForm(stringifyQuery, "scoring", "GET");
                        };

                        $scope.profileType = 'scoring';
                    },
                    resolve: {
                        // resolve scoring here to avoid async issue using deferred API
                        "scoring": function ($q, $route, scoringService) {
                            var scoring = $q.defer();
                            scoringService.getScoring($route.current.params.scoringId).success(function (scoringData) {
                                scoring.resolve(scoringData);
                            });
                            return scoring.promise;
                        }
                    }
                }).
                when('/scoring/:scoringId/profile/:profileId', {
                    templateUrl: ManagersContext.localTemplatesPath + '/profiles/profile-view.html',
                    controller: 'ManageProfileCtrl',
                    resolve: {
                        // resolve profile here to avoid async issue using deferred API
                        "profile": function ($q, $route, profileService) {
                            var profile = $q.defer();
                            profileService.getProfile($route.current.params.profileId).success(function (profileData) {
                                profile.resolve(profileData);
                            });
                            return profile.promise;
                        }
                    }
                }).
                when('/scoring/:scoringId/profile/:profileId/:sessionId', {
                    templateUrl: ManagersContext.localTemplatesPath + '/profiles/profile-session.html',
                    controller: 'ManageSessionCtrl'
                }).
                otherwise({
                    redirectTo: '/scoring'
                });
        }])
;
