wem = {
    setCookie: function (cname, cvalue, exdays) {
        var d = new Date();
        d.setTime(d.getTime() + (exdays*24*60*60*1000));
        var expires = "expires="+d.toUTCString();
        document.cookie = cname + "=" + cvalue + "; " + expires;
    },

    getCookie:function (cname) {
        var name = cname + "=";
        var ca = document.cookie.split(';');
        for(var i=0; i<ca.length; i++) {
            var c = ca[i];
            while (c.charAt(0)==' ') c = c.substring(1);
            if (c.indexOf(name) == 0) return c.substring(name.length,c.length);
        }
        return "";
    },

    registerEvent: function (event) {
        if (window.digitalData) {
            if (window.cxs) {
                console.error("already loaded, too late ..");
            } else {
                window.digitalData.events = window.digitalData.events || [];
                window.digitalData.events.push(event);
            }
        } else {
            window.digitalData = {};
            window.digitalData.events = window.digitalData.events || [];
            window.digitalData.events.push(event);
        }
    },

    registerFilterCallbacks: function (filter, callback) {
        if (window.digitalData) {
            if (window.cxs) {
                console.error("already loaded, too late ..");
            } else {
                console.log("wem: digitalData object present but not loaded, registering filter callback...");
                window.digitalData.filterCallback = window.digitalData.filterCallback || [];
                window.digitalData.filterCallback.push({filter: filter, callback: callback});
            }
        } else {
            window.digitalData = {};
            window.digitalData.filterCallback = window.digitalData.filterCallback || [];
            window.digitalData.filterCallback.push({filter: filter, callback: callback});
        }
    },

    getFilterTargets: function () {
        var targets = [];
        if (window.digitalData.filterCallback) {
            for (var i = 0; i < window.digitalData.filterCallback.length; i++) {
                var currentNodeFilters = window.digitalData.filterCallback[i].filter;
                for (var j = 0; j < currentNodeFilters.filters.length; j++) {
                    var currentNodeFilter = currentNodeFilters.filters[j];
                    for (var k = 0; k < currentNodeFilter.appliesOn.length; k++) {
                        var applyOnEntry = currentNodeFilter.appliesOn[k];
                        targets.push(applyOnEntry);
                    }
                }
            }
        }
        return targets;
    },

    registerCallbacks: function (onLoadCallback) {
        if (window.digitalData) {
            if (window.cxs) {
                console.log("wem: digitalData object loaded, calling on load callback immediately and registering update callback...");
                if (onLoadCallback) {
                    onLoadCallback(window.digitalData);
                }
            } else {
                console.log("wem: digitalData object present but not loaded, registering load callback...");
                if (onLoadCallback) {
                    window.digitalData.loadCallbacks = window.digitalData.loadCallbacks || [];
                    window.digitalData.loadCallbacks.push(onLoadCallback);
                }
            }
        } else {
            console.log("wem: No digital data object found, creating and registering update callback...");
            window.digitalData = {};
            if (onLoadCallback) {
                window.digitalData.loadCallbacks = [];
                window.digitalData.loadCallbacks.push(onLoadCallback);
            }
        }
    },

    resolvePersonalization: function (successfulFilters, noConditionsFilters, filters, strategy, fallback) {
        var selectedFilter;

        if (strategy == "random") {
            function randomIndex(array) {
                return Math.floor(Math.random() * array.length);
            }

            successfulFilters = successfulFilters.concat(noConditionsFilters);
            selectedFilter = successfulFilters[randomIndex(successfulFilters)];
        } else {
            function compareFn(a, b) {
                // sort in reverse order of priority so that the first element is the highest priority one
                return -(a.priority - b.priority);
            }

            // defaults to : (strategy == 'matching-first')
            // if a filter matches, it should be selected before any no-condition ones
            // if we have successful filters, find the one with the highest priority
            if (successfulFilters.length > 0) {
                successfulFilters.sort(compareFn);
                selectedFilter = successfulFilters[0];
            } else {
                // we didn't have an explicit filter match, look at the no conditions ones
                noConditionsFilters.sort(compareFn);
                selectedFilter = noConditionsFilters[0];
            }
        }

        if(!selectedFilter && fallback && filters[fallback]) {
            selectedFilter = {
                "filterId": fallback,
                "variantWrapper": filters[fallback].variantWrapper,
                "variantWrapperPath": filters[fallback].variantWrapperPath,
                "variantPath": filters[fallback].variantPath,
                "pagePath": filters[fallback].pagePath,
                "priority": filters[fallback].priority,
                "content": filters[fallback].content
            }
        }

        return selectedFilter;
    },

    registerPersonalization: function(filters, strategy, target, fallback, ajax, resultCallback) {
        var noConditionsFilters = [];
        for (var filterId in filters) {
            if (filters.hasOwnProperty(filterId)) {
                var filterWrapper = filters[filterId];
                if (filterWrapper.filter.filters.length > 0) {
                    //register filter
                    wem.registerFilterCallbacks(filterWrapper.filter, function () {
                    });
                } else {
                    //no filter assume that the content pass the test
                    noConditionsFilters.push({
                        "filterId": filterId,
                        "variantWrapper": filterWrapper.variantWrapper,
                        "variantWrapperPath": filterWrapper.variantWrapperPath,
                        "variantPath": filterWrapper.variantPath,
                        "pagePath": filterWrapper.pagePath,
                        "priority": filterWrapper.priority,
                        "content": filterWrapper.content
                    })
                }
            }
        }

        // look on filter results and define the content to display base on the strategy
        wem.registerCallbacks(function () {
            var successfulFilters = [];
            for (var filterId in cxs.filteringResults) {
                if (cxs.filteringResults.hasOwnProperty(filterId)) {
                    if (filters.hasOwnProperty(filterId)) {
                        if (cxs.filteringResults[filterId]) {
                            successfulFilters.push({
                                "filterId": filterId,
                                "variantWrapper": filterWrapper.variantWrapper,
                                "variantWrapperPath": filterWrapper.variantWrapperPath,
                                "variantPath": filterWrapper.variantPath,
                                "pagePath": filterWrapper.pagePath,
                                "priority": filters[filterId].priority,
                                "content": filters[filterId].content
                            })
                        }
                    }
                }
            }

            var selectedFilter = wem.resolvePersonalization(successfulFilters, noConditionsFilters, filters, strategy, fallback);

            if (resultCallback != null) {
                // execute callback
                resultCallback(successfulFilters, selectedFilter);
            } else {
                if (selectedFilter) {
                    if (ajax) {
                        wem.loadContent(selectedFilter.content, target);
                    } else {
                        var targetContents = document.getElementById(target).children;
                        for (var index in targetContents) {
                            var el = targetContents.item(index);
                            el.style.display = (el.id == selectedFilter.content)?'':'none';
                        }
                    }
                    var displayWemVariant = new CustomEvent("displayWemVariant", {
                        detail:{
                            variantWrapperPath: selectedFilter.variantWrapperPath,
                            variantPath: selectedFilter.variantPath,
                            pagePath: selectedFilter.pagePath,
                            variantWrapper: selectedFilter.variantWrapper
                        }
                    });
                    document.dispatchEvent(displayWemVariant);
                } else {
                    if (ajax) {
                        document.getElementById(target).innerHTML = '';
                    } else {
                        var elements = document.getElementById(target).children;
                        for (var index in elements) {
                            var el = elements.item(index);
                            el.style.display = 'none';
                        }
                    }
                }
            }
        });
    },

    anonymizeProfile: function (errorID) {
        $.post(wem.proxyServletUrl + '/cxs/privacy/profiles/' + cxs.profileId + '/anonymize')
            .success(function() {
                location.reload();
            })
            .error(function(response) {
                $(errorID).show();
                console.error(response);
            });
    },

    togglePrivateBrowsing: function (errorID) {
        if (cxs.anonymousBrowsing) {
            $.ajax({
                url: wem.proxyServletUrl + '/cxs/privacy/profiles/' + cxs.profileId + '/anonymousBrowsing',
                method: 'DELETE',
                success: function() {
                    location.reload();
                },
                error: function(response) {
                    $(errorID).show();
                    console.error(response);
                }
            })
        } else {
            $.post(wem.proxyServletUrl + '/cxs/privacy/profiles/' + cxs.profileId + '/anonymousBrowsing?anonymizePastBrowsing=true')
                .success(function() {
                    location.reload();
                })
                .error(function(response) {
                    $(errorID).show();
                    console.error(response);
                });
        }
    },

    storageAvailable: function (type) {
        try {
            var storage = window[type],
                x = '__storage_test__';
            storage.setItem(x, x);
            storage.removeItem(x);
            return true;
        }
        catch (e) {
            return false;
        }
    },

    registerOptimizationTest: function (optimizationTestNodeId, goalId, containerId, variants, ajax, variantsTraffic) {
        var selectedVariantId = null;
        if (wem.storageAvailable('sessionStorage')) {
            selectedVariantId = sessionStorage.getItem(optimizationTestNodeId);
        } else {
            selectedVariantId = wem.getCookie('selectedVariantId');
            if (selectedVariantId != null && selectedVariantId == '') {
                selectedVariantId = null;
            }
        }
        if (!(selectedVariantId && variants[selectedVariantId])) {
            var keys = Object.keys(variants);
            if (variantsTraffic) {
                var rand = 100 * Math.random() << 0;
                for (var nodeIdentifier in variantsTraffic) {
                    if ((rand -= variantsTraffic[nodeIdentifier]) < 0 && selectedVariantId == null) {
                        selectedVariantId = nodeIdentifier;
                    }
                }
            } else {
                selectedVariantId = keys[keys.length * Math.random() << 0];
            }
            if (wem.storageAvailable('sessionStorage')) {
                sessionStorage.setItem(optimizationTestNodeId, selectedVariantId);
            } else {
                wem.setCookie('selectedVariantId', selectedVariantId, 1);
            }
            wem.registerEvent({
                eventType: "optimizationTestEvent",
                scope: window.digitalData.scope,
                source: {
                    itemType: "page",
                    scope: window.digitalData.scope,
                    itemId: window.digitalData.page.pageInfo.pageID,
                    properties: window.digitalData.page
                },
                target: {
                    itemType: "optimizationTest",
                    scope: window.digitalData.scope,
                    itemId: optimizationTestNodeId,
                    properties: {
                        variantId: selectedVariantId,
                        goalId: goalId
                    }
                }
            });
        }

        if (selectedVariantId) {
            if (ajax) {
                wem.loadContent(variants[selectedVariantId].content, containerId);
            } else {
                document.getElementById(variants[selectedVariantId].content).style.display = '';
            }
        }
    },

    extractFormData: function (form) {
        var params = {};
        for (var i=0; i < form.elements.length; i++) {
            var e = form.elements[i];
            if (typeof(e.name) != 'undefined') {
                switch (e.nodeName) {
                    case 'TEXTAREA':
                    case "INPUT":
                        switch (e.type) {
                            case 'checkbox':
                                var checkboxes = document.querySelectorAll('input[name="' + e.name + '"]');
                                if(checkboxes.length > 1) {
                                    if(!params[e.name]) {
                                        params[e.name] = [];
                                    }
                                    if(e.checked) {
                                        params[e.name].push(e.value);
                                    }

                                }
                                break;
                            case 'radio':
                                if (e.checked) {
                                    params[e.name] = e.value;
                                }
                                break;
                            default:
                                if (!e.value || e.value == "") {
                                    // ignore element if no value is provided
                                    break;
                                }
                                params[e.name] = e.value;
                        }
                        break;
                    case "SELECT":
                        if (e.options && e.options[e.selectedIndex]) {
                            if(e.multiple){
                                params[e.name] = [];
                                for (var i = 0; i < e.options.length; i++) {
                                    if(e.options[i].selected){
                                        params[e.name].push(e.options[i].value);
                                    }
                                }
                            }else{
                                params[e.name] = e.options[e.selectedIndex].value;
                            }
                        }
                        break;
                }
            }
        }
        return params;
    },

    onreadystatechange: function (xhr, replaceIfExists) {
        if (xhr.readyState == 4) {
            if (xhr.status == 200 || xhr.status == 304) {
                if (xhr.responseText != null) {
                    if (!document.getElementById("contextjs")) {
                        var oHead = document.getElementsByTagName('HEAD').item(0);
                        var oScript = document.createElement("script");
                        oScript.language = "javascript";
                        oScript.type = "text/javascript";
                        oScript.id = "contextjs";
                        oScript.defer = true;
                        oScript.text = xhr.responseText;
                        oHead.appendChild(oScript);
                    } else if (replaceIfExists) {
                        var existingScript = document.getElementById("contextjs");
                        existingScript.parentNode.removeChild(existingScript);
                        var oHead = document.getElementsByTagName('HEAD').item(0);
                        var oScript = document.createElement("script");
                        oScript.language = "javascript";
                        oScript.type = "text/javascript";
                        oScript.id = "contextjs";
                        oScript.defer = true;
                        oScript.text = xhr.responseText;
                        oHead.appendChild(oScript);
                    }
                    return true;
                }
            } else {
                wem.executeFallback();
                console.error('XML request error: ' + xhr.statusText + ' (' + xhr.status + ')');
            }
        }
    },

    executeFallback: function() {
        cxs = {};
        cxs.filteringResults = [];

        for (var index in window.digitalData.loadCallbacks) {
            window.digitalData.loadCallbacks[index]();
        }
    },

    loadContext: function (skipEvents, replaceContextIfExist) {
        var url = wem.contextServerPublicUrl + '/context.js?sessionId=' + wem.sessionID;

        var xhr = new XMLHttpRequest();
        if ("withCredentials" in xhr) {
            xhr.open("POST", url, true);
            xhr.withCredentials = true;
        } else if (typeof XDomainRequest != "undefined") {
            xhr = new XDomainRequest();
            xhr.open("POST", url);
        }

        var wemExecuted = false;
        if (wem.timeoutInMilliseconds != -1) {
            setTimeout(function () {
                if (!wemExecuted) {
                    console.log("timeout, fallback personalization");
                    wemExecuted = true;
                    wem.executeFallback()
                }
            }, wem.timeoutInMilliseconds);
        }

        xhr.onreadystatechange = function () {
            if (!wemExecuted) {
                res = wem.onreadystatechange(xhr, replaceContextIfExist);
                if (res) {
                    wemExecuted = true;
                }
            }
        };
        xhr.setRequestHeader("Content-Type", "text/plain;charset=UTF-8"); // Use text/plain to avoid CORS preflight
        jsonData = {
            source: {
                itemType: "page",
                scope: window.digitalData.scope,
                itemId: window.digitalData.page.pageInfo.pageID,
                properties:window.digitalData.page
            }
        };
        if (!skipEvents) {
            jsonData.events = window.digitalData.events
        }
        if (window.digitalData.filterCallback) {
            jsonData.filters = window.digitalData.filterCallback.map(function(x) {return x.filter})
        }

        xhr.send(JSON.stringify(jsonData));
        console.log("wem: context loading...");
    },

    loadPersonaContext: function (personaId, segmentOverrides, profilePropertiesOverrides, sessionPropertiesOverrides) {
        var url = wem.contextServerPublicUrl + '/context.js?sessionId=' + wem.sessionID + "&personaId=" + personaId;

        var xhr = new XMLHttpRequest();
        if ("withCredentials" in xhr) {
            xhr.open("POST", url, true);
            xhr.withCredentials = true;
        } else if (typeof XDomainRequest != "undefined") {
            xhr = new XDomainRequest();
            xhr.open("POST", url);
        }
        xhr.onreadystatechange = function() {
            wem.onreadystatechange(xhr, true);
        };
        xhr.setRequestHeader("Content-Type", "text/plain;charset=UTF-8"); // Use text/plain to avoid CORS preflight
        jsonData = {
            source: {
                itemType: "page",
                scope: window.digitalData.scope,
                itemId: window.digitalData.page.pageInfo.pageID,
                properties: window.digitalData.page
            },
            requireSegments: true,
            requiredProfileProperties: ['*'],
            requiredSessionProperties: ['*'],
            events: window.digitalData.events,
            segmentOverrides: segmentOverrides,
            profilePropertiesOverrides: profilePropertiesOverrides,
            sessionPropertiesOverrides: sessionPropertiesOverrides
        };
        if (window.digitalData.filterCallback) {
            jsonData.filters = window.digitalData.filterCallback.map(function(x) {return x.filter})
        }
        xhr.send(JSON.stringify(jsonData));
        console.log("wem: persona context loading...");
    },

    loadContent: function(url, parentSelector) {
        var xhr = new XMLHttpRequest();
        var finished = false;
        xhr.onabort = xhr.onerror = function xhrError() {
            finished = true;
        };

        xhr.onreadystatechange = function xhrStateChange() {
            if (xhr.readyState === 4 && !finished) {
                finished = true;
                try {
                    document.getElementById(parentSelector).innerHTML = xhr.responseXML.getElementsByTagName('body')[0].innerHTML;
                } catch (e) {
                    console.log(e);
                }
            }
        };

        xhr.open('GET', url);
        xhr.responseType = 'document';
        xhr.send();
    },

    formFactoryEventCallback: function(event) {
        console.log('Registring Form Factory event callback');
        window.ffCallbacks.registerCallback(event.detail, function (formData, formInfo) {
            if (wem.formNamesToWatch.indexOf(formInfo.formName)) {
                console.info("wem: catching FF form " + event.detail.formName);
                var formEvent = {
                    scope: window.digitalData.scope,
                    eventType: "form",
                    source: {
                        itemType: "page",
                        scope: window.digitalData.scope,
                        itemId: window.digitalData.page.pageInfo.pageID,
                        properties: window.digitalData.page
                    },
                    target: {
                        itemType: "form",
                        scope: window.digitalData.scope,
                        itemId: formInfo.formName
                    },
                    properties: formData.resultData
                };
                wem.sendFormEvent(formEvent);

                formInfo.notifyFormFactoryOfCompletion("MFcallback");
            }
        });
    },

    formEventCallback: function (event) {
        console.log('Registring form event callback');
        // to avoid submitting form factory form with this event
        if (!wem.lastClickedSubmit.formName) {
            return false;
        }
        var form = event.target;
        var formName = form.getAttribute("name") ? form.getAttribute("name") : form.getAttribute("id");
        if (formName && wem.formNamesToWatch.indexOf(formName) > -1) {
            console.info("wem: catching form " + formName);

            var eventCopy = document.createEvent('Event');
            // Define that the event name is 'build'.
            eventCopy.initEvent('submit', event.bubbles, event.cancelable);

            event.stopImmediatePropagation();
            event.preventDefault();

            var formEvent = {
                scope: window.digitalData.scope,
                eventType: "form",
                source:{
                    itemType: "page",
                    scope: window.digitalData.scope,
                    itemId: window.digitalData.page.pageInfo.pageID,
                    properties: window.digitalData.page
                },
                target: {
                    itemType:"form",
                    scope: window.digitalData.scope,
                    itemId:formName
                },
                properties: {}
            };
            // merge form properties with event properties
            var formData =  wem.extractFormData(form);
            for (var formInput in formData) {
                formEvent.properties[formInput]=formData[formInput];
            }

            wem.sendFormEvent(formEvent, form, eventCopy, formName);
        }
    },

    sendFormEvent: function(formEvent, form, eventCopy, formName) {
        cxs.collectEvent(formEvent,
            function () {
                console.info("wem: Form event successfully submitted.");
                if (form) {
                    document.body.removeEventListener('submit', wem.formEventCallback, true);
                    form.dispatchEvent(eventCopy);
                    if (!eventCopy.defaultPrevented && !eventCopy.cancelBubble) {
                        if (wem.lastClickedSubmit['formName'] == formName) {
                            wem.lastClickedSubmit['submitButton'].click();
                        } else {
                            form.submit();
                        }
                    }
                    document.body.addEventListener('submit', wem.formEventCallback, true);
                }
            },
            function (xhr) {
                console.log("wem: Error while collecting form event: " + xhr.status + " " + xhr.statusText);
                xhr.abort();
                if (form) {
                    document.body.removeEventListener('submit', wem.formEventCallback, true);
                    form.dispatchEvent(eventCopy);
                    if (!eventCopy.defaultPrevented && !eventCopy.cancelBubble) {
                        if (wem.lastClickedSubmit['formName'] == formName) {
                            wem.lastClickedSubmit['submitButton'].click();
                        } else {
                            form.submit();
                        }
                    }
                    document.body.addEventListener('submit', wem.formEventCallback, true);
                }
            }
        );
    },

    init: function(contextServerPublicUrl, proxyServletUrl, sessionID, isPreview, timeoutInMilliseconds) {
        wem.contextServerPublicUrl = contextServerPublicUrl;
        wem.proxyServletUrl = proxyServletUrl;
        wem.sessionID = sessionID;
        wem.timeoutInMilliseconds = timeoutInMilliseconds;
        wem.lastClickedSubmit = {};
        wem.formNamesToWatch = [];

        if(isPreview) {
            return;
        }
        if (!navigator.cookieEnabled) {
            wem.loadContext(true, true);
            return;
        }

        // this is the event to get form factory data when submitting
        document.addEventListener('ffFormReady', wem.formFactoryEventCallback);

        wem.registerEvent({
            eventType:"view",
            scope: window.digitalData.scope,
            source:{
                itemType: "site",
                scope: window.digitalData.scope,
                itemId: window.digitalData.site.siteInfo.siteID
            },
            target:{
                itemType: "page",
                scope: window.digitalData.scope,
                itemId: window.digitalData.page.pageInfo.pageID,
                properties: window.digitalData.page
            }
        });

        // process referrer if it exists
        var referrerURL = document.referrer;
        if (referrerURL) {
            // parse referrer URL
            var referrer = document.createElement('a');
            referrer.href = referrerURL;

            // only process referrer if it's not coming from the same site as the current page
            var local = document.createElement('a');
            local.href = document.URL;
            if (referrer.host !== local.host) {
                // get search element if it exists and extract search query if available
                var search = referrer.search;
                var query = undefined;
                if (search && search != "") {
                    // parse parameters
                    var queryParams = [], param;
                    var queryParamPairs = search.slice(1).split('&');
                    for (var i = 0; i < queryParamPairs.length; i++) {
                        param = queryParamPairs[i].split('=');
                        queryParams.push(param[0]);
                        queryParams[param[0]] = param[1];
                    }

                    // try to extract query: q is Google-like (most search engines), p is Yahoo
                    query = queryParams.q || queryParams.p;
                    query = decodeURIComponent(query).replace(/\+/g, ' ');
                }


                // register referrer event
                // Create deep copy of window.digitalData.page and add data to pageInfo sub object
                var properties = jQuery.extend(true, {}, window.digitalData.page);
                properties.pageInfo.referrerHost = referrer.host;
                properties.pageInfo.referrerQuery = query;
                
                wem.registerEvent({
                    eventType: "viewFromReferrer",
                    scope: window.digitalData.scope,
                    target: {
                        itemType: "page",
                        scope: window.digitalData.scope,
                        itemId: window.digitalData.page.pageInfo.pageID,
                        properties: properties
                    }
                });
            }
        }

        document.addEventListener('DOMContentLoaded', function() {
            wem.loadContext()
        });

        // Capture all submit at document level
        wem.registerCallbacks(function() {
            document.cookie="context-profile-id-copy="+cxs.profileId + "; path=/";
            // process tracked events
            var videoNamesToWatch = [];
            if(cxs.trackedConditions && cxs.trackedConditions.length > 0){
                for (var i = 0; i < cxs.trackedConditions.length; i++) {
                    switch (cxs.trackedConditions[i].type) {
                        case "formEventCondition":
                            if(cxs.trackedConditions[i].parameterValues && cxs.trackedConditions[i].parameterValues.formId){
                                wem.formNamesToWatch.push(cxs.trackedConditions[i].parameterValues.formId)
                            }
                            break;
                        case "videoViewEventCondition":
                            if(cxs.trackedConditions[i].parameterValues && cxs.trackedConditions[i].parameterValues.videoId){
                                videoNamesToWatch.push(cxs.trackedConditions[i].parameterValues.videoId)
                            }
                            break;
                    }
                }
            }

            document.body.addEventListener('submit', wem.formEventCallback, true);

            console.info("wem: watching forms");
            $('input[type="submit"], button[type="submit"]').click(function(event) {
                var form = $(event.target).closest('form');
                var formName = form.attr('name') ? form.attr('name') : form.attr('id');
                if (formName && wem.formNamesToWatch.indexOf(formName) > -1) {
                    wem.lastClickedSubmit['formName'] = formName;
                    wem.lastClickedSubmit['submitButton'] = event.target
                }
            });

            // register video events
            sendVideoEvent = function(event){
                console.info("wem: catching video event");
                var videoId = event.target.id;
                var videoEvent = {
                    scope: window.digitalData.scope,
                    eventType: "video",
                    source:{
                        itemType: "page",
                        scope: window.digitalData.scope,
                        itemId: window.digitalData.page.pageInfo.pageID,
                        properties: window.digitalData.page
                    },
                    target: {
                        itemType:"video",
                        scope: window.digitalData.scope,
                        itemId:videoId
                    },
                    properties: {
                        "event":event.type
                    }
                };

                cxs.collectEvent(videoEvent,
                    function () {
                        console.log("wem: Video event successfully collected.");
                    }
                );
            };

            for (var j = 0; j < videoNamesToWatch.length; j++) {
                var videoName = videoNamesToWatch[j];
                var video = $("#" + videoName);
                if(video){
                    video.on('play',sendVideoEvent);
                    video.on('ended',sendVideoEvent);
                    console.info("wem: watching video "+videoName);
                } else {
                    console.log("wem: unable to watch video " + videoName + ", video not found in the page");
                }
            }
        });

    }

};


